@@ -109,12 +109,15 @@ class Player(Generator):
             self._afile = afile
             self._loop = loop
             self._samples = afile.frames
+            self._firstread = False
             super().__init__(out_buffer=True,  # The _out_buf is used to write the file into on _inc()
                              blocksize=blocksize,
                              start_frame=start_frame)
 
         def _mod(self, outdata: "ABlock", ch: int) -> None:
-            return super()._mod(outdata, ch)
+            if not self._firstread:
+                self._inc()
+                self._firstread = True
 
         def _inc(self) -> None:
             if self.finished_event.is_set():
@@ -139,13 +142,14 @@ class Player(Generator):
 
         def _reset(self) -> None:
             self._afile.seek(0)
+            # clear events
             self.looped_event.clear()
             self.finished_event.clear()
+            # clear queues
             while not self.seek_queue.empty():
                 self.seek_queue.get(block=False)
-            # load the first frame into _out_buffer
-            self._inc()
-            return super()._reset()
+            # reset firstread
+            self._firstread = False
 
 
 class Sine(Generator):
@@ -219,9 +223,9 @@ class Sine(Generator):
 
         def _reset(self) -> None:
             self._phase = self._start_phase
+            # clear queues
             while not self.frequency_queue.empty():
                 self.frequency_queue.get(block=False)
-            return super()._reset()
 
 
 class SineBurst(Generator):
@@ -276,7 +280,7 @@ class SineBurst(Generator):
         def _mod(self, outdata: "ABlock", ch: int) -> None:
             if self._phase < self._maxang:
                 np.sin(self._omegas + self._phase, out=outdata)
-                outdata[self._omegas >= self._maxang] = 0
+                outdata[self._omegas + self._phase >= self._maxang] = 0
 
         def _inc(self) -> None:
             if self._phase < self._maxang:
@@ -284,9 +288,9 @@ class SineBurst(Generator):
 
         def _reset(self) -> None:
             self._phase = self._start_phase
+            # clear queues
             while not self.frequency_queue.empty():
                 self.frequency_queue.get(block=False)
-            return super()._reset()
 
 
 class Vector(Generator):
@@ -357,8 +361,8 @@ class Vector(Generator):
 
         def _reset(self) -> None:
             self._pos = 0
+            # clear events
             self.finished_event.clear()
-            return super()._reset()
 
 
 class Noise(Generator):
@@ -391,11 +395,13 @@ class Noise(Generator):
             self._rnd_spec = pyfftw.empty_aligned(int(blocksize / 2 + 1), dtype=np.complex64)
             self._fftw = pyfftw.FFTW(self._tmp,
                                      self._rnd_spec,
-                                     axes=(0, ))
+                                     axes=(0, ),
+                                     flags=('FFTW_ESTIMATE', ))
             self._ifftw = pyfftw.FFTW(self._rnd_spec,
                                       self._tmp,
                                       axes=(0, ),
-                                      direction="FFTW_BACKWARD")
+                                      direction="FFTW_BACKWARD",
+                                      flags=('FFTW_ESTIMATE', ))
 
             self._rng = np.random.default_rng()
             # weighting
@@ -434,7 +440,7 @@ class Noise(Generator):
             self._tmp /= norm
 
         def _reset(self) -> None:
-            return super()._reset()
+            return None
 
 
 class Constant(Generator):
@@ -466,7 +472,7 @@ class Constant(Generator):
             outdata[:] = self._value
 
         def _inc(self) -> None:
-            return super()._inc()
+            return None
 
         def _reset(self) -> None:
-            return super()._reset()
+            return None
