@@ -399,7 +399,7 @@ class Interface(Processor):
                 return
 
         if self._is_driver(drivers=("CoreAudio", )):
-            raise NotImplementedError("CoreAudio channel selection is not tested!")
+            logger.warning("CoreAudio channel selection is not tested!")
             if self._iinputs:
                 # convert to channel names starting with 0
                 in_channels = [inpu.channel - 1 for inpu in self._iinputs]
@@ -411,7 +411,8 @@ class Interface(Processor):
                     return
 
             if self._ioutputs:
-                out_channels = [-1] * sd.query_devices(device=self._device, kind="output")["max_output_channels"]
+                out_channels = [-1] * sd.query_devices(device=self._device[1].index,
+                                                       kind="output")["max_output_channels"]
                 for idx, c in enumerate(self._ioutputs):
                     out_channels[c.channel - 1] = idx
                 ca_out = sd.CoreAudioSettings(channel_map=out_channels)
