@@ -125,6 +125,10 @@ class Effect(Processor):
     def outputs(self) -> Tuple["Output", ...]:
         return self._outputs
 
+    @property
+    def inputs(self) -> Tuple[Input, ...]:
+        return self._inputs
+
     def input(self, idx: int = 0) -> "Input":
         """Get the Input for the given index.
         For multiple input Effects that support input-update.
@@ -186,7 +190,7 @@ class Effect(Processor):
         # disconnect all inputs
         for inpu in self._inputs:
             outp = inpu.connected_output
-            if isinstance(outp, Output):
+            if outp is not None:
                 outp.disconnect(inpu)
         # reset input list
         self._inputs = ()
@@ -277,7 +281,7 @@ class Analyzer(Processor):
         # disconnect all inputs
         for inpu in self._inputs:
             outp = inpu.connected_output
-            if isinstance(outp, Output):
+            if outp is not None:
                 outp.disconnect(inpu)
         # reset input list
         self._inputs = ()
