@@ -1,5 +1,5 @@
 """This file stores abreviation of complex custom types."""
-from typing import Callable, Optional, Protocol, Tuple, TypeAlias, Union
+from typing import Callable, Literal, Optional, Protocol, Tuple, TypeAlias, TypedDict
 
 import numpy as np
 import numpy.typing as npt
@@ -7,7 +7,7 @@ import sounddevice as sd
 
 from .acore import AAnalyzer, AEffect, AGenerator, AInterface
 
-InA: TypeAlias = Union[AGenerator, AEffect, AInterface]
+InA: TypeAlias = AGenerator | AEffect | AInterface
 """Type for ACore devices that can connect to inputs"""
 
 InAs = Tuple[Tuple[Optional[InA], int], ...]
@@ -54,11 +54,10 @@ ABuffer = npt.NDArray[np.float32]
 """Type for multi channel audio data block stored in buffers of ACore devices.
 ABuffer.shape = (samples, channels)"""
 
-ACore = Union[AGenerator, AAnalyzer, AEffect, AInterface]
+ACore = AGenerator | AAnalyzer | AEffect | AInterface
 """Type collecting all ACore devices."""
 
-Device = Union[Tuple[Union[int, str, None], Union[int, str, None]],
-               Union[int, str, None]]
+Device = Tuple[int | str | None, int | str | None] | int | str | None
 """Type for specifying audio device(s) to the Interface class on initialization."""
 
 
@@ -76,3 +75,46 @@ Callback = Callable[["npt.NDArray[np.float32]",
                      sd.CallbackFlags],
                     None]
 """Type used to reflect sounddevice's calback function."""
+
+
+class InterfaceIOTD(TypedDict, total=False):
+    """Typed properties for InterfaceIO classes.
+
+    Attributes:
+        name: Trivial name.
+        reference: Flag if the channel is used as reference for computation/calibration.
+        gain: The gain setting of the input.
+        latency: Individual IO latency (relative to Interface's system latency).
+        color: A color used for plotting.
+        cPa: Pressure calibration factor in Pascal.
+        fPa: Frequency used for pressure calibration.
+        datePa: Date of last pressure calibration (ISO 8601).
+        cV: Voltage calibration factor in Volts.
+        fV: Frequency used for voltage calibration.
+        dateV: Date of last voltage calibration (ISO 8601).
+        cA: Acceleration calibration factor in m/s^2.
+        fA: Frequency used for acceleration calibration.
+        dateA: Date of last acceleration calibration (ISO 8601).
+        cFR: Frequency response calibration vector.
+        fFR: Corresponding frequency vector.
+        pos: Position vector.
+    """
+    # when PEP728 releases, we can also allow optional kwargs
+    # https://peps.python.org/pep-0728/
+    reference: Literal[True] | None
+    name: str | None
+    gain: float | None
+    latency: int | None
+    color: str | None
+    cPa: float | None
+    fPa: float | None
+    datePa: str | None
+    cV: float | None
+    fV: float | None
+    dateV: str | None
+    cA: float | None
+    fA: float | None
+    dateA: str | None
+    cFR: npt.NDArray[np.complex64] | None
+    fFR: npt.NDArray[np.float32] | None
+    pos: Tuple[float, float, float] | None
